@@ -665,6 +665,10 @@ class Trainer:
 			res = func(*args,**params,**kwargs)
 			return res
 		return wrapper
+	def test(self):
+		raise NotImplementedError
+	def predict(self,x):
+		raise NotImplementedError
 	def train(self, model=None, device=None, train_data_loader=None, val_data_loader=None, criterion=None,
 	          optimizer=None, lr_scheduler=None, start_global_step=None, start_epoch=None, num_epochs=None):
 		'''
@@ -804,6 +808,8 @@ class ClassifierTrainer(Trainer):
 		)
 		self.log(log)
 
+class KeypointDetectorTrainer(Trainer):
+	pass
 
 def demo():
 	trainer = ClassifierTrainer()
